#
# spec file for package ghc-riak
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name riak
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.1.2.0
Release:        lp150.1.4
Summary:        A Haskell client for the Riak decentralized data store
License:        Apache-2.0
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-blaze-builder-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-default-class-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-enclosed-exceptions-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-mersenne-random-pure64-devel
BuildRequires:  ghc-monad-control-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-protocol-buffers-devel
BuildRequires:  ghc-pureMD5-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-resource-pool-devel
BuildRequires:  ghc-riak-protobuf-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-semigroups-devel
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-base-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-yaml-devel
%endif

%description
A Haskell client library for the Riak decentralized data store, designed for
efficiency, ease of use, and flexibility. Uses the Riak protocol buffers API
for speed.

This library is organized to allow a tradeoff between power and ease of use.
If you would like a different degree of automation with storage and conflict
resolution, you may want to use one of the following modules (ranked from
easiest to most tricky to use):

[Network.Riak] JSON for storage, automatic conflict resolution. This is the
easiest module to work with.

[Network.Riak.JSON] JSON for storage, manual conflict resolution.

[Network.Riak.Value.Resolvable] More complex (but still automatic) storage,
automatic conflict resolution.

[Network.Riak.Value] More complex (but still automatic) storage, manual
conflict resolution.

[Network.Riak.Basic] manual storage, manual conflict resolution. This is the
most demanding module to work with, as you must encode and decode data
yourself, and handle all conflict resolution yourself

[Network.Riak.CRDT] CRDT operations.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cabal-tweak-dep-ver vector '< 0.12' ' < 1'

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc Changes.md README.markdown

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Fri Jul 28 2017 psimons@suse.com
- Relax the over-specified version constraint on vector.
* Wed May 31 2017 psimons@suse.com
- Update to version 1.1.2.0.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.1.1.0 with cabal2obs.
